==> haskell-js-jquery-3.3.1-1082-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-jquery
version:              3.3.1
visibility:           public
id:                   js-jquery-3.3.1-KvUst5ffo9rLu3TI505Rt
key:                  js-jquery-3.3.1-KvUst5ffo9rLu3TI505Rt
license:              MIT
copyright:            Neil Mitchell 2014-2018
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-jquery#readme
synopsis:             Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  3eddbb2bf0d059535bf41630b3efcd07
exposed:              True
exposed-modules:      Language.Javascript.JQuery
hidden-modules:       Paths_js_jquery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-jquery
hs-libraries:         HSjs-jquery-3.3.1-KvUst5ffo9rLu3TI505Rt
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html:         /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-jquery-3.3.1-1085-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-jquery
version:              3.3.1
visibility:           public
id:                   js-jquery-3.3.1-507PnuxOO2RCKssn2OYlgl
key:                  js-jquery-3.3.1-507PnuxOO2RCKssn2OYlgl
license:              MIT
copyright:            Neil Mitchell 2014-2018
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-jquery#readme
synopsis:             Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  11c8671a2555c5c925a7a06080d8bd6d
exposed:              True
exposed-modules:      Language.Javascript.JQuery
hidden-modules:       Paths_js_jquery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-jquery
hs-libraries:         HSjs-jquery-3.3.1-507PnuxOO2RCKssn2OYlgl
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html:         /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
